@@ -1,4 +1,4 @@
-# Copyright (C) 2009 - 2020  Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2009 - 2021  Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -33,7 +33,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
     env <- parent.frame(1)
 
     if (!is.character(cpp_files))
-        stop("'cpp_files' must be a character vector")
+        stop("'cpp_files' must be a character vector")				# #nocov
 
     if (!length(list)) {
         fake <- TRUE
@@ -46,12 +46,12 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
         }
     } else {
         if (example_code && !isTRUE(attributes)) {
-            if (!"rcpp_hello_world" %in% list) {
+            if (!"rcpp_hello_world" %in% list) {					# #nocov start
                 assign( "rcpp_hello_world", function() {}, envir = env)
                 call[["list"]] <- as.call(c(as.name("c"),
                                             as.list(c("rcpp_hello_world", list))))
             }
-            remove_hello_world <- TRUE
+            remove_hello_world <- TRUE								# #nocov end
         } else {
             remove_hello_world <- FALSE
         }
@@ -69,7 +69,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
     }
 
     tryCatch(eval(call, envir = env), error = function(e){
-        stop(sprintf("error while calling `package.skeleton` : %s", conditionMessage(e)))
+        stop(sprintf("error while calling `package.skeleton` : %s", conditionMessage(e)))	# #nocov
     })
 
     message("\nAdding Rcpp settings")
@@ -81,18 +81,27 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
     DESCRIPTION <- file.path(root, "DESCRIPTION")
     if (file.exists(DESCRIPTION)) {
         imports <- c(if (isTRUE(module)) "methods", sprintf("Rcpp (>= %s)", getRcppVersion()))
-        x <- cbind(read.dcf(DESCRIPTION),
+        splitname <- strsplit(author, " ")[[1]]
+        x <- cbind(read.dcf(DESCRIPTION,  fields = c("Package", "Type", "Title", "Version", "Date",
+                                                     "Description", "License")),
                    "Imports" = paste(imports, collapse = ", "),
-                   "LinkingTo" = "Rcpp")
-        x[, "Author"] <- author
-        x[, "Maintainer"] <- sprintf("%s <%s>", maintainer, email)
+                   "LinkingTo" = "Rcpp",
+                   "Authors@R" = sprintf("person(\"%s\", \"%s\", role = c(\"aut\", \"cre\"), email = \"%s\")",
+                                         paste(splitname[-length(splitname)], collapse=" "),
+                                         splitname[length(splitname)],
+                                         email))
+        #x[, "Author"] <- author
+        #x[, "Maintainer"] <- sprintf("%s <%s>", maintainer, email)
         x[, "License"] <- license
-        x[, "Title"] <- "What the Package Does in One 'Title Case' Line"
-        x[, "Description"] <- "One paragraph description of what the package does as one or more full sentences."
+        x[, "Title"] <- "Concise Summary of What the Package Does"
+        x[, "Description"] <- "More about what it does (maybe more than one line)."
         message( " >> added Imports: Rcpp" )
         message( " >> added LinkingTo: Rcpp" )
         write.dcf(x, file = DESCRIPTION)
-
+        write.dcf(x[1, c("Package", "Type", "Title", "Version", "Date",
+                         "Authors@R", "Description", "License", "Imports", "LinkingTo"),
+                    drop = FALSE],
+                  file = DESCRIPTION)
     }
 
     ## add useDynLib and importFrom to NAMESPACE
@@ -103,7 +112,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
         if (getRversion() >= "3.4.0") {
             lines <- c(sprintf( "useDynLib(%s, .registration=TRUE)", name), lines)
         } else {
-            lines <- c(sprintf( "useDynLib(%s)", name), lines)
+            lines <- c(sprintf( "useDynLib(%s)", name), lines)				# #nocov
         }
         writeLines(lines, con = ns)
         message(" >> added useDynLib directive to NAMESPACE" )
@@ -124,7 +133,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
     if (havePkgKitten) {                # if pkgKitten is available, use it
         pkgKitten::playWithPerPackageHelpPage(name, path, maintainer, email)
     } else {
-        .playWithPerPackageHelpPage(name, path, maintainer, email)
+        .playWithPerPackageHelpPage(name, path, maintainer, email)			# #nocov
     }
 
     ## lay things out in the src directory
@@ -135,9 +144,9 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
     skeleton <- system.file("skeleton", package = "Rcpp")
 
     if (length(cpp_files) > 0L) {
-        for (file in cpp_files) {
+        for (file in cpp_files) {											# #nocov start
             file.copy(file, src)
-            message(" >> copied ", file, " to src directory" )
+            message(" >> copied ", file, " to src directory" )				# #nocov end
         }
     }
 
@@ -190,7 +199,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
             close(con)
             message(" >> created init.c for package registration")
         } else {
-            message(" >> R version older than 3.4.0 detected, so NO file init.c created.")
+            message(" >> R version older than 3.4.0 detected, so NO file init.c created.")	# #nocov
         }
     }
 
@@ -232,7 +241,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
                                         path = ".",
                                         maintainer = "Your Name",
                                         email = "your@mail.com") {
-    root <- file.path(path, name)
+    root <- file.path(path, name)										# #nocov start
     helptgt <- file.path(root, "man", sprintf( "%s-package.Rd", name))
     helpsrc <- system.file("skeleton", "manual-page-stub.Rd", package="Rcpp")
     ## update the package description help page
@@ -244,5 +253,5 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
                       lines, fixed = TRUE)
         writeLines(lines, helptgt)
     }
-    invisible(NULL)
+    invisible(NULL)														# #nocov end
 }
