@@ -33,11 +33,11 @@ public:
 
 	IsNa( const BASE& obj_) : obj(obj_){}
 
-	inline int operator[]( int i ) const {
+        inline int operator[]( R_xlen_t i ) const {
 		return ::Rcpp::traits::is_na<RTYPE>( obj[i] ) ;
 	}
 
-	inline int size() const { return obj.size() ; }
+        inline R_xlen_t size() const { return obj.size() ; }
 
 private:
 	const BASE& obj ;
@@ -55,11 +55,11 @@ public:
 
 	IsNa( const BASE& obj_) : obj(obj_){}
 
-	inline int operator[]( int i ) const {
+        inline int operator[]( R_xlen_t i ) const {
 		return FALSE ;
 	}
 
-	inline int size() const { return obj.size() ; }
+        inline R_xlen_t size() const { return obj.size() ; }
 
 private:
 	const BASE& obj ;
@@ -71,11 +71,15 @@ class IsNa_Vector_is_na : public Rcpp::VectorBase<LGLSXP, false, IsNa_Vector_is_
    public:
        IsNa_Vector_is_na( const T& x) : ref(x){}
 
-       inline int operator[]( int i) const {
+       inline int operator[]( R_xlen_t i) const {
+       #if defined(RCPP_NEW_DATE_DATETIME_VECTORS)
+           return ::Rcpp::traits::is_na<T>(ref[i]);
+       #else
            return ref[i].is_na() ;
+       #endif
        }
 
-       inline int size() const { return ref.size() ; }
+       inline R_xlen_t size() const { return ref.size() ; }
 
    private:
         const T& ref ;
@@ -84,17 +88,26 @@ class IsNa_Vector_is_na : public Rcpp::VectorBase<LGLSXP, false, IsNa_Vector_is_
 } // sugar
 
 template <int RTYPE, bool NA, typename T>
-inline sugar::IsNa<RTYPE,NA,T> is_na( const Rcpp::VectorBase<RTYPE,NA,T>& t){
-	return sugar::IsNa<RTYPE,NA,T>( t ) ;
+inline sugar::IsNa<RTYPE,NA,T> is_na( const Rcpp::VectorBase<RTYPE,NA,T>& t) {
+    return sugar::IsNa<RTYPE,NA,T>(t);
 }
 
-inline sugar::IsNa_Vector_is_na<DatetimeVector> is_na( const DatetimeVector& x){
-    return sugar::IsNa_Vector_is_na<DatetimeVector>( x ) ;
+inline sugar::IsNa_Vector_is_na<oldDatetimeVector> is_na(const oldDatetimeVector& x) {
+    return sugar::IsNa_Vector_is_na<oldDatetimeVector>( x ) ;
 }
-inline sugar::IsNa_Vector_is_na<DateVector> is_na( const DateVector& x){
-    return sugar::IsNa_Vector_is_na<DateVector>( x ) ;
+
+inline sugar::IsNa_Vector_is_na<oldDateVector> is_na(const oldDateVector& x) {
+    return sugar::IsNa_Vector_is_na<oldDateVector>(x);
 }
 
+inline sugar::IsNa_Vector_is_na<NumericVector> is_na(newDatetimeVector& x) {
+    return sugar::IsNa_Vector_is_na<NumericVector>(x);
+}
+inline sugar::IsNa_Vector_is_na<NumericVector> is_na(newDateVector& x) {
+    return sugar::IsNa_Vector_is_na<NumericVector>(x);
+}
+
+
 } // Rcpp
 #endif
 
