@@ -22,6 +22,8 @@
 #ifndef Rcpp__traits__named_object__h
 #define Rcpp__traits__named_object__h
 
+#include <type_traits>
+
 namespace Rcpp{
 class Argument ;
 
@@ -63,6 +65,19 @@ template <typename T> struct is_named : public false_type{};
 template <typename T> struct is_named< named_object<T> > : public true_type {};
 template <> struct is_named< Rcpp::Argument > : public true_type {};
 
+
+#if defined(HAS_VARIADIC_TEMPLATES)
+    template <typename... T> struct is_any_named : public false_type {};
+    template <typename T> struct is_any_named<T> : public is_named<T>::type {};
+
+    template <typename T, typename... TArgs>
+    struct is_any_named<T, TArgs...>
+        : public std::conditional<
+                    is_any_named<T>::value,
+                    std::true_type,
+                    is_any_named<TArgs...>>::type {};
+#endif
+
 } // namespace traits
 } // namespace Rcpp
 
