@@ -3,7 +3,7 @@
 //
 // r_sexptype_traits.h: Rcpp R/C++ interface class library -- traits to help wrap
 //
-// Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2013 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -27,22 +27,24 @@ namespace Rcpp{
 namespace traits{
 
 /**
- * template that returns the SEXP type that is appropriate for 
+ * template that returns the SEXP type that is appropriate for
  * the type T, this is allways VECSXP (lists) unless it is specialized
  */
 template <typename T> struct r_sexptype_traits{ enum{ rtype = VECSXP }; } ;
 template<> struct r_sexptype_traits<int>{ enum{ rtype = INTSXP } ; } ;
 template<> struct r_sexptype_traits<const int>{ enum{ rtype = INTSXP } ; } ;
 template<> struct r_sexptype_traits<double>{ enum{ rtype = REALSXP } ; } ;
+template<> struct r_sexptype_traits<const double>{ enum{ rtype = REALSXP } ; } ;
 template<> struct r_sexptype_traits<bool>{ enum{ rtype = LGLSXP } ; } ;
 template<> struct r_sexptype_traits<std::string>{ enum{ rtype = STRSXP } ; } ;
 template<> struct r_sexptype_traits<Rcomplex>{ enum{ rtype = CPLXSXP } ; } ;
 template<> struct r_sexptype_traits<Rbyte>{ enum{ rtype = RAWSXP } ; } ;
 
-template<> struct r_sexptype_traits<unsigned int>{ enum{ rtype = INTSXP } ; } ;
+
+template<> struct r_sexptype_traits<unsigned int>{ enum{ rtype = REALSXP } ; } ;
 template<> struct r_sexptype_traits<float>{ enum{ rtype = REALSXP } ; } ;
 
-/* long are represented as numeric vectors which allows more precision 
+/* long are represented as numeric vectors which allows more precision
    to be preserved than int */
 template<> struct r_sexptype_traits<long>{ enum{ rtype = REALSXP } ; } ;
 template<> struct r_sexptype_traits<unsigned long>{ enum{ rtype = REALSXP } ; } ;
@@ -57,21 +59,14 @@ template<> struct r_sexptype_traits<long double>{ enum{ rtype = REALSXP } ; } ;
 template<> struct r_sexptype_traits<short>{ enum{ rtype = INTSXP } ; } ;
 template<> struct r_sexptype_traits<unsigned short>{ enum{ rtype = INTSXP } ; } ;
 
-/* long long int */
-#ifdef RCPP_HAS_LONG_LONG_TYPES
-template<> struct r_sexptype_traits<rcpp_long_long_type>{ enum{ rtype = REALSXP } ; } ;
-template<> struct r_sexptype_traits<rcpp_ulong_long_type>{ enum{ rtype = REALSXP } ; } ;
-#endif
-
 /* std::complex */
 template<> struct r_sexptype_traits< std::complex<double> >{ enum{ rtype = CPLXSXP } ; } ;
 template<> struct r_sexptype_traits< std::complex<float> >{ enum{ rtype = CPLXSXP } ; } ;
 
-
 /**
  * Indicates if a primitive type needs a static_cast
  */
-template <typename T> struct r_sexptype_needscast : public true_type{}; 
+template <typename T> struct r_sexptype_needscast : public true_type{};
 template<> struct r_sexptype_needscast<int>          : public false_type{} ;
 template<> struct r_sexptype_needscast<double>       : public false_type{} ;
 template<> struct r_sexptype_needscast<Rcomplex>     : public false_type{} ;
