@@ -22,11 +22,15 @@
 #define COMPILING_RCPP
 
 #define USE_RINTERNALS
-#include <Rinternals.h>
-#include <Rcpp/barrier.h>
-#include "internal.h"
+
 #include <algorithm>
+#include <Rinternals.h>
+
+#include <Rcpp/barrier.h>
 #include <Rcpp/protection/Shield.h>
+#include <Rcpp/r/compat.h>
+
+#include "internal.h"
 
 // [[Rcpp::register]]
 SEXP get_string_elt(SEXP x, R_xlen_t i) {			// #nocov start
@@ -50,7 +54,8 @@ void char_set_string_elt(SEXP x, R_xlen_t i, const char* value) {
 
 // [[Rcpp::register]]
 SEXP* get_string_ptr(SEXP x) {
-    return STRING_PTR(x);
+    // TODO: should we deprecate this?
+    return const_cast<SEXP*>(RCPP_STRING_PTR(x));
 }
 
 // [[Rcpp::register]]
@@ -65,7 +70,8 @@ void set_vector_elt(SEXP x, R_xlen_t i, SEXP value) {
 
 // [[Rcpp::register]]
 SEXP* get_vector_ptr(SEXP x) {
-    return VECTOR_PTR(x);							// #nocov end
+    // TODO: should we deprecate this?
+    return const_cast<SEXP*>(RCPP_VECTOR_PTR(x));							// #nocov end
 }
 
 // [[Rcpp::register]]
